/*
 *  OMIKUJI Machine for STM32F401re nucleo board
 *
 *  Copyright(C) by YI Studio
 */

#include <stm32f4xx.h>


/**************************************************
    read button port
**************************************************/
int  btn_stat( void )
{
    int  stat = 0 ;
    unsigned int  data ;

    data = GPIOC->IDR ;

    /* on board button */
    if( (data & (1 << 13)) == 0 ) {
        stat |= 0x01 ;
    }

    /* TUTU */
    if( (data & (1 << 8)) == 0 ) {
        stat |= 0x02 ;
    }

    /* Ext-Sw */
    if( (data & (1 << 9)) == 0 ) {
        stat |= 0x04 ;
    }

    return( stat ) ;
}


/**************************************************
    initialize button port
**************************************************/
void  btn_init( void )
{
    /* clock enable */
    RCC->AHB1ENR |= RCC_AHB1ENR_GPIOCEN ;

    /* on board button */
    /** for BTN:PC13 **/
    GPIOC->MODER   &= ~(0x0c000000);
    GPIOC->PUPDR   &= ~(0x0c000000);
    GPIOC->PUPDR   |=  (0x04000000); /* PULL-UP */

    /* TUTU */
    /** for BTN:PC8 **/
    GPIOC->MODER   &= ~(0x00030000);
    GPIOC->PUPDR   &= ~(0x00030000);
    GPIOC->PUPDR   |=  (0x00010000); /* PULL-UP */

    /* Ext-Sw */
    /** for BTN:PC9 **/
    GPIOC->MODER   &= ~(0x000c0000);
    GPIOC->PUPDR   &= ~(0x000c0000);
    GPIOC->PUPDR   |=  (0x00040000); /* PULL-UP */
}


/**************************************************
    set LED port
**************************************************/
void  led_set( int led )
{
    if( led & 0x0001 ) {
        /* LED on */
        GPIOA->BSRR = 0x0020 ;

        /* Ext-LED on */
        GPIOC->BSRR = 0x0020 ;
    } else {
        /* LED off */
        GPIOA->BSRR = 0x0020 <<16 ;

        /* ExtLED off */
        GPIOC->BSRR = 0x0020 <<16 ;
    }
}

/**************************************************
    initialize LED port
**************************************************/
void  led_init( void )
{
    /* clock enable */
    RCC->AHB1ENR |= ( RCC_AHB1ENR_GPIOAEN 
                    | RCC_AHB1ENR_GPIOCEN) ;

    /** for LED:PA5 **/
    GPIOA->MODER   &= ~(0x00000c00);
    GPIOA->MODER   |=  (0x00000400);
    GPIOA->OTYPER  &= ~(0x0020);
    GPIOA->OSPEEDR &= ~(0x00000c00);
    GPIOA->OSPEEDR |=  (0x00000800);
    GPIOA->PUPDR   &= ~(0x00000c00);
    GPIOA->PUPDR   |=  (0x00000400);

    /** for Ext-LED:PC5 **/
    GPIOC->MODER   &= ~(0x00000c00);
    GPIOC->MODER   |=  (0x00000400);
    GPIOC->OTYPER  &= ~(0x0020);
    GPIOC->OSPEEDR &= ~(0x00000c00);
    GPIOC->OSPEEDR |=  (0x00000800);
    GPIOC->PUPDR   &= ~(0x00000c00);
    GPIOC->PUPDR   |=  (0x00000400);
}

